==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ja.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "使用状況レポート",
    "An error occurred while sending your report." : "レポート送信中にエラーが発生しました。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "アプリ一覧 <em>(各アプリ: 名前、バージョン、有効か無効か)</em>",
    "Database environment <em>(type, version, database size)</em>" : "データベース環境 <em>(種類、バージョン、データベースサイズ)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "暗号化情報 <em>(有効かどうか、デフォルトモジュールの種類)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "共有の数 <em>(種類ごとならびにパーミッション設定)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP環境 <em>(バージョン、メモリ上限、最大実行時間、最大ファイルサイズ)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "サーバーインスタンスの詳細 <em>(バージョン、memcacheの利用、locking/previews/avatarsの状況)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "統計 <em>(総数: ファイル数、ユーザー数、ストレージ種類数、コメントとタグ数)</em>",
    "Help improve Nextcloud" : "Nextcloudの改善を助けてください",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloudの改善に役立てるため、設定ならびに使用状況の一部を匿名化したデータを、提供していただけないでしょうか？ この設定は、いつでも管理者設定から無効にできます。",
    "Not now" : "あとで",
    "Send usage" : "使用状況を送信",
    "Never" : "使用しない",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "設定ならびに使用状況に関する一部のデータを送信していただくと、Nextcloudの改善に役立ちます。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "プライバシー情報について慎重に取り扱います。データは、明示的にオンを選択しなければデフォルトでは送信されませんし、オンにした場合でも、まず匿名化された上にどのデータを送信するか選択することができます。レポートを受け取ったら、古いデータは削除されます。レポートの削除を受け取ったら現在あるサーバー上のすべてのデータを削除します。",
    "Send new report now" : "新しい使用状況レポートを送信",
    "Send usage survey monthly" : "使用状況レポートを毎月送信する",
    "Data to send" : "送信データ",
    "Last report" : "新しいレポート",
    "Sent on: {on}" : "送信オン: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "アプリリスト <em>(アプリ毎: 名前, バージョン, 有効か無効か)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "サーバー設定状況 <em>(バージョン, memcache の利用, locking/previews/avatars の利用の有無)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "設定ならびに使用状況に関する一部のデータを送信していただくと、Nextcloudの改善に役立ちます。",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "プライバシー情報について慎重に取り扱います。データ匿名化され、いつでも有効/無効を切り替えられます、デフォルトでは送信されません。どのデータを送信するか選択することができますし、どの情報を最新のレポートで送信したかいつでも見ることができます。新しいレポートをサーバーが受け取ったら、あなたのサーバーのすべての古いレポートを削除します。また、下記の設定で無効にしたものがあれば、新しいレポートを送信して今あるサーバー上のすべてのデータを削除することができます。",
    "Sent on: %s" : "送信オン: %s"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ja.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "使用状況レポート",
    "Last report sent on: {on}" : "最新のレポート送信時刻: {on}",
    "An error occurred while sending your report." : "レポート送信中にエラーが発生しました。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "アプリ一覧 <em>(各アプリ: 名前、バージョン、有効か無効か)</em>",
    "Database environment <em>(type, version, database size)</em>" : "データベース環境 <em>(種類、バージョン、データベースサイズ)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "暗号化情報 <em>(有効かどうか、デフォルトモジュールの種類)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "共有の数 <em>(種類ごとならびにパーミッション設定)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP環境 <em>(バージョン、メモリ上限、最大実行時間、最大ファイルサイズ)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "サーバーインスタンスの詳細 <em>(バージョン、memcacheの利用、locking/previews/avatarsの状況)</em>",
    "Help improve Nextcloud" : "Nextcloudの改善を助けてください",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloudの改善に役立てるため、設定ならびに使用状況の一部を匿名化したデータを、提供していただけないでしょうか？ この設定は、いつでも管理者設定から無効にできます。",
    "Not now" : "あとで",
    "Send usage" : "使用状況を送信",
    "Never" : "使用しない",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "設定ならびに使用状況に関する一部のデータを送信していただくと、Nextcloudの改善に役立ちます。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "プライバシー情報について慎重に取り扱います。データは、明示的にオンを選択しなければデフォルトでは送信されませんし、オンにした場合でも、まず匿名化された上にどのデータを送信するか選択することができます。レポートを受け取ったら、古いデータは削除されます。レポートの削除を受け取ったら現在あるサーバー上のすべてのデータを削除します。",
    "Send new report now" : "新しい使用状況レポートを送信",
    "Send usage survey monthly" : "使用状況レポートを毎月送信する",
    "Data to send" : "送信データ",
    "Last report sent on: %s" : "最新のレポート送信時刻: %s",
    "Last report" : "最新のレポート"
},
"nplurals=1; plural=0;");
